@@ -1,3 +1,5 @@
+"""Cryptography-related utilities."""
+import subprocess
 from pathlib import Path
 
 
@@ -8,6 +10,6 @@ def read_gpg_token(p: Path) -> str:
     """
 
     proc = subprocess.run(
-        ["gpg", "--decrypt", "-q", p], capture_output=True, timeout=3, check=True
+        ["gpg", "--decrypt", "-q", str(p)], capture_output=True, timeout=3, check=True
     )
-    return proc.stdout.decode("utf-8")
+    return proc.stdout.decode("utf-8").rstrip("\n")
